==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/CancellingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancellingMultiScaleImageEventArgsDescription } from "./CancellingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
var CancellingMultiScaleImageEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CancellingMultiScaleImageEventArgsDescriptionMetadata, _super);
    function CancellingMultiScaleImageEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancellingMultiScaleImageEventArgsDescriptionMetadata.b = function (a) {
        if (CancellingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
            CancellingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancellingMultiScaleImageEventArgsDescriptionMetadata.c(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        if (a.j(CancellingMultiScaleImageEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.c = function (a) {
        a.item("Uri", "String");
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.d = function (a) {
        CancellingMultiScaleImageEventArgsDescriptionMetadata.b(a);
        a.aa("CancellingMultiScaleImageEventArgs", function () { return new CancellingMultiScaleImageEventArgsDescription(); });
        a.z("CancellingMultiScaleImageEventArgs", CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.$t = markType(CancellingMultiScaleImageEventArgsDescriptionMetadata, 'CancellingMultiScaleImageEventArgsDescriptionMetadata');
    CancellingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return CancellingMultiScaleImageEventArgsDescriptionMetadata;
}(Base));
export { CancellingMultiScaleImageEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/CancellingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancellingMultiScaleImageEventArgsDescription } from "./CancellingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
var CancellingMultiScaleImageEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CancellingMultiScaleImageEventArgsDescriptionMetadata, _super);
    function CancellingMultiScaleImageEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancellingMultiScaleImageEventArgsDescriptionMetadata.b = function (a) {
        if (CancellingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
            CancellingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancellingMultiScaleImageEventArgsDescriptionMetadata.c(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        if (a.k(CancellingMultiScaleImageEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.c = function (a) {
        a.item("Uri", "String");
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.d = function (a) {
        CancellingMultiScaleImageEventArgsDescriptionMetadata.b(a);
        a.ac("CancellingMultiScaleImageEventArgs", function () { return new CancellingMultiScaleImageEventArgsDescription(); });
        a.ab("CancellingMultiScaleImageEventArgs", CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.$t = markType(CancellingMultiScaleImageEventArgsDescriptionMetadata, 'CancellingMultiScaleImageEventArgsDescriptionMetadata');
    CancellingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return CancellingMultiScaleImageEventArgsDescriptionMetadata;
}(Base));
export { CancellingMultiScaleImageEventArgsDescriptionMetadata };
